==> aac-0.1.2-py3-none-any.whl: aac/plugins/validators/validator_implementation/_validator_implementation.py <==
import logging

from aac.lang.language_context import LanguageContext
from aac.lang.definitions.definition import Definition
from aac.lang.definitions.structure import get_substructures_by_type
from aac.plugins.plugin_manager import get_validator_plugins
from aac.plugins.validators import ValidatorResult, ValidatorPlugin


def validate_validator_implementations(definition_under_test: Definition, target_schema_definition: Definition, language_context: LanguageContext, *validation_args) -> ValidatorResult:
    """
    Validates that the validation definition has a corresponding registered ValidatorPlugin.

    Args:
        definition_under_test (Definition): The definition that's being validated. (Root validation definitions)
        target_schema_definition (Definition): A definition with applicable validation. ("Validation" definition)
        language_context (LanguageContext): The language context.

    Returns:
        A ValidatorResult containing any applicable error messages.
    """
    error_messages = []

    def validate_dict(dict_to_validate: dict) -> list[str]:

        def get_validator_by_name(name: str, plugins: list[ValidatorPlugin]) -> ValidatorPlugin:
            return list(filter(lambda plugin: plugin.name == name, plugins))

        validator_implementations = get_validator_plugins()
        validation_name = dict_to_validate.get("name")

        validation_plugins = get_validator_by_name(validation_name, validator_implementations)

        if not validation_plugins:
            registered_plugin_names = [plugin.name for plugin in validator_implementations]
            registered_plugin_names = f"Validation '{validation_name}' did not have a corresponding implementation. Registered plugin names: {registered_plugin_names}"
            error_messages.append(registered_plugin_names)
            logging.debug(registered_plugin_names)
        elif validation_plugins and not len(validation_plugins) == 1:
            registered_plugin_names = [plugin.name for plugin in validator_implementations]
            registered_plugin_names = f"Validation '{validation_name}' returned multiple corresponding implementations. Matching plugins: {validation_plugins}"
            error_messages.append(registered_plugin_names)
            logging.debug(registered_plugin_names)

    dicts_to_test = get_substructures_by_type(definition_under_test, target_schema_definition, language_context)
    list(map(validate_dict, dicts_to_test))

    return ValidatorResult(error_messages, len(error_messages) == 0)

==> aac-0.1.4-py3-none-any.whl: aac/plugins/validators/validator_implementation/_validator_implementation.py <==
import logging

from aac.lang.language_context import LanguageContext
from aac.lang.definitions.definition import Definition
from aac.lang.definitions.structure import get_substructures_by_type
from aac.plugins.plugin_manager import get_validator_plugins
from aac.plugins.validators import ValidatorFindings, ValidatorResult, ValidatorPlugin


PLUGIN_NAME = "Validation definition has an implementation"


def validate_validator_implementations(definition_under_test: Definition, target_schema_definition: Definition, language_context: LanguageContext, *validation_args) -> ValidatorResult:
    """
    Validates that the validation definition has a corresponding registered ValidatorPlugin.

    Args:
        definition_under_test (Definition): The definition that's being validated. (Root validation definitions)
        target_schema_definition (Definition): A definition with applicable validation. ("Validation" definition)
        language_context (LanguageContext): The language context.

    Returns:
        A ValidatorResult containing any applicable error messages.
    """
    findings = ValidatorFindings()

    def validate_dict(dict_to_validate: dict) -> None:
        def get_validator_by_name(name: str, plugins: list[ValidatorPlugin]) -> list[ValidatorPlugin]:
            return list(filter(lambda plugin: plugin.name == name, plugins))

        validator_implementations = get_validator_plugins()
        validation_name = dict_to_validate.get("name")

        validation_plugins = get_validator_by_name(validation_name, validator_implementations)

        if not validation_plugins:
            registered_plugin_names = [plugin.name for plugin in validator_implementations]
            registered_plugin_names = f"Validation '{validation_name}' did not have a corresponding implementation. Registered plugin names: {registered_plugin_names}"
            findings.add_error_finding(target_schema_definition, registered_plugin_names, PLUGIN_NAME, 0, 0, 0, 0)
            logging.debug(registered_plugin_names)
        elif validation_plugins and not len(validation_plugins) == 1:
            registered_plugin_names = [plugin.name for plugin in validator_implementations]
            registered_plugin_names = f"Validation '{validation_name}' returned multiple corresponding implementations. Matching plugins: {validation_plugins}"
            findings.add_error_finding(target_schema_definition, registered_plugin_names, PLUGIN_NAME, 0, 0, 0, 0)
            logging.debug(registered_plugin_names)

    dicts_to_test = get_substructures_by_type(definition_under_test, target_schema_definition, language_context)
    list(map(validate_dict, dicts_to_test))

    return ValidatorResult(definition_under_test, findings)
